codegen

package
v0.0.0-...-d6b0b83 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 11, 2026 License: BSD-3-Clause Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EscapeString

func EscapeString(s string) string

EscapeString returns a Go-safe quoted string body (not surrounding quotes).

func RuntimeStub

func RuntimeStub() string

RuntimeStub returns a small comment stub explaining runtime helpers link.

func TrimTrailingWhitespace

func TrimTrailingWhitespace(src string) string

TrimTrailingWhitespace normalizes generated code by trimming trailing spaces on each line. Small helper for code formatting before writing to disk.

Types

This section is empty.

Jump to