runtimelib

package
v0.0.0-...-d6b0b83 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 11, 2026 License: BSD-3-Clause Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateTemp

func CreateTemp(prefix string) string

CreateTemp creates an empty temp file and returns its full path (empty on error).

func Remove

func Remove(path string) int

Remove deletes the given path. Returns 0 on success, 1 on failure.

func WriteTemp

func WriteTemp(prefix, data string) string

WriteTemp writes data into a new temp file and returns its full path (empty on error).

Types

This section is empty.

Jump to