Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EscapeString ¶
EscapeString returns a Go-safe quoted string body (not surrounding quotes).
func RuntimeStub ¶
func RuntimeStub() string
RuntimeStub returns a small comment stub explaining runtime helpers link.
func TrimTrailingWhitespace ¶
TrimTrailingWhitespace normalizes generated code by trimming trailing spaces on each line. Small helper for code formatting before writing to disk.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.